@@ -23,13 +23,14 @@ from contextlib import contextmanager
 from dataclasses import dataclass
 from datetime import date, timedelta
 from time import sleep
-from typing import Optional
+from typing import Iterable, Optional, cast
 
 import daiquiri
 import gitlab
 import typer
-from gitlab.v4.objects import VISIBILITY_PUBLIC, DeployKey, Project, ProjectPipelineSchedule, User
-from gitlab.v4.objects.variables import Variable
+from gitlab.const import Visibility
+from gitlab.v4.objects import DeployKey, Project, ProjectCommit, ProjectKey, ProjectPipelineSchedule, User
+from gitlab.v4.objects.variables import ProjectVariable
 
 from ..app_args import check_provider_slug_is_lowercase, get_fetcher_def_not_found_error_message
 from ..gitlab import init_gitlab_client
@@ -207,7 +208,7 @@ def get_deploy_key_title(ctx: Context):
     return f"{ctx.provider_slug} {CI_JOBS_KEY}"
 
 
-def find_variable_by_name(project: Project, name: str) -> Optional[Variable]:
+def find_variable_by_name(project: Project, name: str) -> Optional[ProjectVariable]:
     try:
         return project.variables.get(name)
     except gitlab.exceptions.GitlabGetError as exc:
@@ -224,8 +225,8 @@ def find_deploy_key_by_title(ctx: Context, title: str) -> Optional[DeployKey]:
     return None
 
 
-def find_project_deploy_key_by_title(project: Project, title: str) -> Optional[DeployKey]:
-    for key in project.keys.list(as_list=False):
+def find_project_deploy_key_by_title(project: Project, title: str) -> Optional[ProjectKey]:
+    for key in cast(Iterable[ProjectKey], project.keys.list(as_list=False)):
         if key.title == title:
             return key
     return None
@@ -425,14 +426,17 @@ def create_or_update_pipeline_variables(fetcher_project: Project, variables: dic
 
 
 def create_pipeline_schedule(project: Project, schedule_def: ScheduleDef, ctx: Context) -> ProjectPipelineSchedule:
-    schedule = project.pipelineschedules.create(
-        {
-            "active": True,
-            "description": "Run fetcher",
-            "ref": project.default_branch or DEFAULT_BRANCH,
-            "cron": schedule_def.cron,
-            "cron_timezone": schedule_def.timezone,
-        }
+    schedule = cast(
+        ProjectPipelineSchedule,
+        project.pipelineschedules.create(
+            {
+                "active": True,
+                "description": "Run fetcher",
+                "ref": project.default_branch or DEFAULT_BRANCH,
+                "cron": schedule_def.cron,
+                "cron_timezone": schedule_def.timezone,
+            }
+        ),
     )
     take_ownership(schedule, schedule_def.owner, ctx)
     logger.info("%r created for %r with owner %r", schedule, project.path_with_namespace, schedule_def.owner)
@@ -489,7 +493,7 @@ def setup_pipeline_schedules(project: Project, fetcher_def: FetcherDef, ctx: Con
 
     schedule_defs = fetcher_def.schedules.copy()
 
-    for schedule in project.pipelineschedules.list(as_list=False):
+    for schedule in cast(Iterable[ProjectPipelineSchedule], project.pipelineschedules.list(as_list=False)):
         schedule_def_index = find_index(
             lambda schedule_def: schedule_def.cron == schedule.cron and schedule_def.timezone == schedule.cron_timezone,
             schedule_defs,
@@ -514,7 +518,7 @@ def setup_pipeline_schedules(project: Project, fetcher_def: FetcherDef, ctx: Con
 def create_project(group_name: str, project_name: str, description: str, ctx: Context):
     group = load_or_create_group(group_name, ctx)
     project = ctx.gl.projects.create(
-        {"name": project_name, "namespace_id": group.id, "description": description, "visibility": VISIBILITY_PUBLIC}
+        {"name": project_name, "namespace_id": group.id, "description": description, "visibility": Visibility.PUBLIC}
     )
     logger.info("Project created: %r", project.path_with_namespace)
     return project
@@ -553,7 +557,7 @@ def fork_project(upstream_project: Project, group_name: str, project_name: str,
     group = load_or_create_group(group_name, ctx)
     project_fork = upstream_project.forks.create({"namespace_id": group.id, "path": project_name})
     project = ctx.gl.projects.get(project_fork.id)
-    commits = []
+    commits: list[ProjectCommit] = []
     while True:
         try:
             commits = project.commits.list(per_page=1)
